==> xl-devops-as-code-common-10.0.1-sources.jar: com/xebialabs/ascode/exception/AsCodeException.scala <==
package com.xebialabs.ascode.exception

import java.util

import com.xebialabs.ascode.yaml.dto.AsCodeResponse.{CiValidationError, DocumentFieldError, PermissionError}
import com.xebialabs.deployit.plugin.api.udm.ConfigurationItem
import com.xebialabs.deployit.service.validation.Validator.ValidationsFailedException

import scala.collection.convert.ImplicitConversions._

object AsCodeException {
  private def getCause(e: Throwable): Throwable = Option(e.getCause) match {
    case Some(cause) => getCause(cause)
    case None => e
  }

  def wrapUnhandled[T](op: => T): T = {
    try {
      op
    } catch {
      case e: Throwable => getCause(e) match {
        case ex: AsCodeException => throw ex
        case ex: ValidationsFailedException => throw CiValidationException({
          val items = ex.getEntity match {
            case collection: util.Collection[_] => collection.toList
            case iterable: Iterable[_] => iterable.toList
          }
          items
            .asInstanceOf[List[ConfigurationItem]]
            .flatMap(_.get$validationMessages())
            .map(message => CiValidationError(message.getCiId, message.getPropertyName, message.getMessage))
        })
        case ex: Throwable => throw new AsCodeException(cause = ex)
      }
    }
  }

  def throwDocumentFieldException(field: String, problem: String): Nothing = {
    throw DocumentValidationException(DocumentFieldError(field, problem))
  }

  def throwCiFieldValidationException(id: String, field: String, problem: String): Nothing = {
    throw CiValidationException(CiValidationError(id, field, problem) :: Nil)
  }
}

case class CiPermissionException(permissionErrors: List[PermissionError]) extends AsCodeException

case class CiValidationException(errors: List[CiValidationError]) extends AsCodeException

case class DocumentValidationException(error: DocumentFieldError) extends AsCodeException

class AsCodeException(msg: String = null, cause: Throwable = null) extends RuntimeException(msg, cause)

==> xl-devops-as-code-common-25.1.0-1001.1305-sources.jar: com/xebialabs/ascode/exception/AsCodeException.scala <==
package com.xebialabs.ascode.exception

import java.util
import com.xebialabs.ascode.yaml.dto.AsCodeResponse.{CiValidationError, DocumentFieldError, PermissionError}
import com.xebialabs.deployit.plugin.api.udm.ConfigurationItem
import com.xebialabs.deployit.service.validation.Validator.ValidationsFailedException

import scala.annotation.tailrec
import scala.jdk.CollectionConverters._

object AsCodeException {
  @tailrec
  private def getCause(e: Throwable): Throwable = Option(e.getCause) match {
    case Some(cause) => getCause(cause)
    case None => e
  }

  def wrapUnhandled[T](op: => T): T = {
    try {
      op
    } catch {
      case e: Throwable => getCause(e) match {
        case ex: AsCodeException => throw ex
        case ex: ValidationsFailedException => throw CiValidationException({
          val items = ex.getEntity match {
            case collection: util.Collection[_] => collection.asScala.toList
            case iterable: Iterable[_] => iterable.toList
          }
          items
            .asInstanceOf[List[ConfigurationItem]]
            .flatMap(_.get$validationMessages().asScala)
            .map(message => CiValidationError(message.getCiId, message.getPropertyName, message.getMessage))
        })
        case ex: Throwable => throw new AsCodeException(cause = ex)
      }
    }
  }

  def throwDocumentFieldException(field: String, problem: String): Nothing = {
    throw DocumentValidationException(DocumentFieldError(field, problem))
  }

  def throwCiFieldValidationException(id: String, field: String, problem: String): Nothing = {
    throw CiValidationException(CiValidationError(id, field, problem) :: Nil)
  }
}

case class CiPermissionException(permissionErrors: List[PermissionError]) extends AsCodeException

case class CiValidationException(errors: List[CiValidationError]) extends AsCodeException

case class DocumentValidationException(error: DocumentFieldError) extends AsCodeException

class AsCodeException(msg: String = null, cause: Throwable = null) extends RuntimeException(msg, cause)
